@@ -31,17 +31,10 @@ class contextItem(object):
     def getLiteral(self):
         return self.__literal
     def getCategory(self):
-        return self.__category
+        return self.__category[:]
     def categoryString(self):
         return u'_'.join(self.__category)
 
-    def replaceCategory(self,oldCategory,newCategory):
-        print "in replaceCategory"
-        for index, item in enumerate(self.__category):
-            print index,item,oldCategory
-            if item == oldCategory.lower().strip():
-                print "replacing %s with %s"%(item,newCategory)
-                self.__category[index] = newCategory.lower().strip()
 
     def isA(self,testCategory):
         try:
