@@ -102,6 +102,7 @@ class tagObject(object):
         variants
         """
         self.__item = item
+        self.__category = self.__item.getCategory()
         self.__spanStart = 0
         self.__spanEnd = 0
         self.__foundPhrase = ''
@@ -181,15 +182,23 @@ class tagObject(object):
         return self.__item.getLiteral()
     def getCategory(self):
         """returns the category (e.g. CONJUNCTION) for this object"""
-        return self.__item.getCategory()
+        return self.__category[:]
     def categoryString(self):
-        return self.__item.categoryString()
+        return u'_'.join(self.__category)
     def isA(self,category):
         return self.__item.isA(category)
     def setCategory(self,category):
-        self.__item.__category = category
+        self.__category = category
     def replaceCategory(self,oldCategory,newCategory):
-        self.__item.replaceCategory(oldCategory,newCategory)
+        for index, item in enumerate(self.__category):
+            #print index,item,oldCategory
+            if item == oldCategory.lower().strip():
+                try:
+                    self.__category[index] = newCategory.lower().strip()
+                except:
+                    del self.__category[index]
+                    self.__category.extend([nc.lower().strip() for nc in newCategory])
+
     def setSpan(self,span):
         """set the span within the associated text for this object"""
         self.__spanStart = span[0]
